/*
 * Tapiocaui app
 * Copyright (C) 2005 INdT
 * @author Renato Araujo Oliveira Filho <renato.filho@indt.org.br>
 * @author Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 * @author Abner Jose de Faria Silva <abner.silva@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA02111-1307USA
 */

#ifndef __TAPIOCAUI_MAINWIN_H__
#define __TAPIOCAUI_MAINWIN_H__

#include <gtk/gtkwidget.h>
#include <gtk/gtkwindow.h>
#include "tapiocaui_db.h"
#include "tapiocaui_communication.h"

G_BEGIN_DECLS

#define TAPIOCAUI_TYPE_MAIN_WIN         (tapiocaui_main_win_get_type ())
#define TAPIOCAUI_MAIN_WIN(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), TAPIOCAUI_TYPE_MAIN_WIN, TapiocaUIMainWin))
#define TAPIOCAUI_MAIN_WIN_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), TAPIOCAUI_TYPE_MAIN_WIN, TapiocaUIMainWinClass))
#define TAPIOCAUI_IS_MAIN_WIN(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), TAPIOCAUI_TYPE_MAIN_WIN))
#define TAPIOCAUI_IS_MAIN_WIN_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), TAPIOCAUI_TYPE_MAIN_WIN))
#define TAPIOCAUI_MAIN_WIN_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TAPIOCAUI_TYPE_MAIN_WIN, TapiocaUIMainWinClass))

typedef struct _TapiocaUIMainWin        TapiocaUIMainWin;
typedef struct _TapiocaUIMainWinClass   TapiocaUIMainWinClass;
typedef struct _TapiocaUIMainWinPrivate TapiocaUIMainWinPrivate;

struct _TapiocaUIMainWinClass
{
    GtkWindowClass parent_class;
  
    void (* login)                  (const gchar *user_id);
    void (* login_cancelled)        (const gchar *user_id);
    void (* logout)                 (void);    
    void (* call)                   (const gchar *user_id);
    void (* open_chat)              (const gchar *user_id);
    void (* buddy_added)            (const gchar *user_id);
    void (* buddy_removed)          (const gchar *user_id);
    void (* buddy_updated)          (const gchar *new_user,
                                     const gchar *old_user);
    void (* account_status_updated) (guint        status,
                                     const        gchar *status_desc);
};

struct _TapiocaUIMainWin {
    GtkWindow parent;
    
    TapiocaUIMainWinPrivate *priv;
};

GType                   tapiocaui_main_win_get_type     (void);
TapiocaUIMainWin       *tapiocaui_main_win_new          (TapiocaUIDB        *db);
TapiocaUICommunication *tapiocaui_main_win_open_chat    (TapiocaUIMainWin   *self,
                                                         TapiocaUIBuddyData *buddy);
void                    tapiocaui_main_win_login        (TapiocaUIMainWin   *self);
void                    tapiocaui_main_win_cancel_login (TapiocaUIMainWin   *self,
                                                         gint                status);
const gchar            *tapiocaui_main_win_get_user     (TapiocaUIMainWin   *self);
void                    tapiocaui_main_win_logout       (TapiocaUIMainWin   *self);
void                    tapiocaui_main_win_load_buddy   (TapiocaUIMainWin   *self,
                                                         TapiocaUIDB        *db,
                                                         const gchar        *user_id);
void                    tapiocaui_main_win_update_buddy (TapiocaUIMainWin   *self);

G_END_DECLS

#endif
