/*
 * Tapiocaui app
 * Copyright (C) 2005 INdT
 * @author Renato Araujo Oliveira Filho <renato.filho@indt.org.br>
 * @author Abner Jose de Faria Silva <abner.silva@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA02111-1307USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <glade/glade.h>
#include <glib/gi18n.h>
#include <gtk/gtkstock.h>
#include <gtk/gtkentry.h>
#include <gtk/gtkmessagedialog.h>

#include <tapioca/client/tapioca.h>

#include "tapiocaui_new_account_dialog.h"
#include "tapiocaui_utils.h"

struct _TapiocaUINewAccountDialogPrivate
{
    GtkWidget *entry_name;
    GtkWidget *entry_id;
    GtkWidget *btn_add;
    TapiocaUIBuddyData *edit_account;
    TapiocaUIDB *db;
};

static void     tapiocaui_new_account_dialog_class_init (TapiocaUINewAccountDialogClass *k);
static void     tapiocaui_new_account_dialog_init       (TapiocaUINewAccountDialog *self);
static void     tapiocaui_new_account_dialog_finalize   (GObject *object);
static gboolean tapiocaui_new_account_dialog_entry_cb   (GtkWidget *widget,
                                                         gpointer user_data);
static void     tapiocaui_new_account_dialog_reponse_cb (GtkDialog *dialog,
                                                         gint arg1,
                                                         gpointer user_data);

static GObjectClass *parent_class = NULL;

G_DEFINE_TYPE (TapiocaUINewAccountDialog, tapiocaui_new_account_dialog, GTK_TYPE_DIALOG)

static void
tapiocaui_new_account_dialog_class_init (TapiocaUINewAccountDialogClass *k)
{
    GObjectClass *object_class = G_OBJECT_CLASS (k);
    parent_class = g_type_class_peek_parent (k);
    object_class->finalize = tapiocaui_new_account_dialog_finalize;
}

static void
tapiocaui_new_account_dialog_init (TapiocaUINewAccountDialog *self)
{
    GladeXML *xml;

    self->priv = g_new0 (TapiocaUINewAccountDialogPrivate, 1);

    g_signal_connect (G_OBJECT (self),
                      "response",
                      G_CALLBACK (tapiocaui_new_account_dialog_reponse_cb),
                      self);

    gtk_dialog_set_default_response (GTK_DIALOG (self),
                                     GTK_RESPONSE_OK);

    gtk_window_set_title (GTK_WINDOW (self), _("New Account"));
    gtk_dialog_add_button (GTK_DIALOG (self),
                           GTK_STOCK_CANCEL,
                           GTK_RESPONSE_CANCEL);

    self->priv->btn_add = gtk_dialog_add_button (GTK_DIALOG (self),
                                                 GTK_STOCK_OK,
                                                 GTK_RESPONSE_OK);
    gtk_widget_set_sensitive (self->priv->btn_add, FALSE);

    xml = glade_xml_new (tapiocaui_file ("new-account-dialog.glade"), "box_info", NULL);
    glade_xml_signal_autoconnect (xml);
    gtk_container_add (GTK_CONTAINER (GTK_DIALOG (self)->vbox),
                                glade_xml_get_widget (xml, "box_info"));

    self->priv->entry_name = glade_xml_get_widget (xml, "entry_name");
    self->priv->entry_id = glade_xml_get_widget (xml, "entry_id");

    g_signal_connect (G_OBJECT (self->priv->entry_name),
                      "changed",
                      G_CALLBACK (tapiocaui_new_account_dialog_entry_cb),
                      self);
    g_signal_connect (G_OBJECT (self->priv->entry_id),
                      "changed",
                      G_CALLBACK (tapiocaui_new_account_dialog_entry_cb),
                      self);

    g_object_unref (G_OBJECT (xml));
}

static void
tapiocaui_new_account_dialog_finalize (GObject *object)
{
    TapiocaUINewAccountDialog *self;

    g_return_if_fail (object != NULL);
    g_return_if_fail (TAPIOCAUI_IS_NEW_ACCOUNT_DIALOG (object));

    self = TAPIOCAUI_NEW_ACCOUNT_DIALOG (object);
    g_free (self->priv);

    G_OBJECT_CLASS (parent_class)->finalize (object);
}

GtkWidget *
tapiocaui_new_account_dialog_new (TapiocaUIDB *db)
{
    TapiocaUINewAccountDialog *self;
    self = g_object_new (TAPIOCAUI_TYPE_NEW_ACCOUNT_DIALOG, NULL);
    self->priv->db = db;
    return GTK_WIDGET (self);
}

static void 
tapiocaui_new_account_dialog_reponse_cb (GtkDialog *dialog,
                                         gint response_id,
                                         gpointer user_data)
{
    TapiocaUIBuddyData *account;
    TapiocaUINewAccountDialog *self = (TapiocaUINewAccountDialog *) user_data;

    if (response_id != GTK_RESPONSE_OK)
        return;

/*    if (!tapioca_is_valid_uri (gtk_entry_get_text (GTK_ENTRY (self->priv->entry_id)))) {
            GtkWidget *dialog;
            dialog = gtk_message_dialog_new (GTK_WINDOW (self),
                                             GTK_DIALOG_MODAL,
                                             GTK_MESSAGE_ERROR,
                                             GTK_BUTTONS_CLOSE,
                                             _("Invalid URI."));
            gtk_dialog_run (GTK_DIALOG (dialog));
            gtk_widget_destroy (dialog);
            return;            
    }*/
        
    if (self->priv->edit_account) {
        account = self->priv->edit_account;
    } else {
        account = tapiocaui_db_find_buddy_by_id (self->priv->db, 
                                                 TAPIOCAUI_DB_ENTRY_ACCOUNT,
                                                 gtk_entry_get_text (GTK_ENTRY (self->priv->entry_id)));
        if (account) {
            GtkWidget *dialog;
            dialog = gtk_message_dialog_new (GTK_WINDOW (self),
                                             GTK_DIALOG_MODAL,
                                             GTK_MESSAGE_ERROR,
                                             GTK_BUTTONS_CLOSE,
                                             _("Account already exists."));
            gtk_dialog_run (GTK_DIALOG (dialog));
            gtk_widget_destroy (dialog);
            return;
        }
        account = tapiocaui_db_entry_new (TAPIOCAUI_DB_ENTRY_ACCOUNT);
    }

    account->id = g_strdup (gtk_entry_get_text (GTK_ENTRY (self->priv->entry_id)));
    account->name = g_strdup (gtk_entry_get_text (GTK_ENTRY (self->priv->entry_name)));

    // TODO
    // Create this field on dialog.
    account->group = g_strdup ("default group");

    if (!self->priv->edit_account) {
        tapiocaui_db_insert_buddy (self->priv->db, account);
    } else {
        tapiocaui_db_notify_change (self->priv->db);
    }
    tapiocaui_db_commit (self->priv->db);
}

static gboolean
tapiocaui_new_account_dialog_entry_cb (GtkWidget *widget,
                                       gpointer user_data)
{
    TapiocaUINewAccountDialog *self = TAPIOCAUI_NEW_ACCOUNT_DIALOG (user_data);

    gchar *entry_id;
    gchar *entry_name;

    entry_id = g_strdup (gtk_entry_get_text (GTK_ENTRY (self->priv->entry_id)));
    entry_name = g_strdup (gtk_entry_get_text (GTK_ENTRY (self->priv->entry_name)));
    
    g_strstrip (entry_id);
    g_strstrip (entry_name);
    
    if ((g_utf8_strlen (entry_id, -1) > 0) &&
        (g_utf8_strlen (entry_name, -1) > 0)) {
        gtk_widget_set_sensitive (GTK_WIDGET (self->priv->btn_add), TRUE);
    } else {
        gtk_widget_set_sensitive (GTK_WIDGET (self->priv->btn_add), FALSE);
    }

    g_free (entry_id);
    g_free (entry_name);

    return  FALSE;
}
