/*
 * Tapiocaui app
 * Copyright (C) 2005 INdT
 * @author Renato Araujo Oliveira Filho <renato.filho@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA02111-1307USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <glib/ghash.h>
#include <glib/gfileutils.h>
#include <glib/gmessages.h>
#include <glib/gstrfuncs.h>
#include <glib/gmem.h>
#include <glib/gutils.h>
#include <glib/gthread.h>

#include <time.h>

#include "tapiocaui_utils.h"

static GHashTable *files = NULL;

const gchar *
tapiocaui_file (const gchar *filename)
{
    gchar *ret;
    gint i;

    static char *paths[] = {
        SHARE_DIR "/",
        SHARE_DIR "/tapiocaui/",
        SHARE_DIR "/pixmaps/tapiocaui/",
#ifdef DEVEL
        "../data/",
        "../pixmaps/",
#endif
    };

    if (files == NULL) {
        files = g_hash_table_new_full (g_str_hash,
                                       g_str_equal,
                                       (GDestroyNotify) g_free,
                                       (GDestroyNotify) g_free);
    }

    ret = g_hash_table_lookup (files, filename);
    if (ret != NULL)
        return ret;

    g_assert (filename != NULL);

    for (i = 0; i < G_N_ELEMENTS (paths); ++i) {
        ret = g_strconcat (paths[i], filename, NULL);
        if (g_file_test (ret, G_FILE_TEST_EXISTS) == TRUE) {
            g_hash_table_insert (files, g_strdup (filename), ret);
            return ret;
        }
        g_free (ret);
    }

    return NULL;
}

void
tapiocaui_real_debug (const char *func,
                      const char *file,
                      int line,
                      const char *format, ...)
{
    va_list args;
    char buffer[1025];
    char *str_time;
    time_t the_time;

    va_start (args, format);

    g_vsnprintf (buffer, 1024, format, args);

    va_end (args);

    time (&the_time);
    str_time = g_new0 (char, 255);
    strftime (str_time, 254, "%H:%M:%S", localtime (&the_time));

    g_printerr ("[%p] [%s] %s:%d (%s): %s\n", 
                g_thread_self (), func, file, line, str_time, buffer);

    g_free (str_time);
}
